; 
; Exports of file WebCheck.dll
;
; Autogenerated by gen_exportdef
; Written by Kai Tietz, 2007
;
LIBRARY WebCheck.dll
EXPORTS
XMLScheduleElementToTaskTrigger
DllCanUnloadNow
DllGetClassObject
DllInstall
DllRegisterServer
DllUnregisterServer
