;
; Definition file of SrumSvc.dll
; Automatic generated by gendef
; written by Kai Tietz 2008-2014
;
LIBRARY "SrumSvc.dll"
EXPORTS
WdiDiagnosticModuleMain
WdiGetDiagnosticModuleInterfaceVersion
WdiHandleInstance
